@@ -1,7 +1,6 @@
-from nonebot import get_bot
+from nonebot.adapters import Bot
 
-async def get_guild_all_channel(guild_id, no_cache=True):
-    bot = get_bot("bot_id")
+async def get_guild_all_channel(guild_id, bot:Bot, no_cache=True):
     datas = await bot.call_api("get_guild_channel_list", guild_id = guild_id, no_cache = no_cache)
     result = []
     for i in datas:
